@@ -15,13 +15,13 @@ var searchData=
   ['addtounsignvector_12',['addToUnsignVector',['../namespace_pro_s_h_a_d_e__internal__misc.html#a16336bdf0b391c953a549d3df115d691',1,'ProSHADE_internal_misc']]],
   ['addtounsignvectorvector_13',['addToUnsignVectorVector',['../namespace_pro_s_h_a_d_e__internal__misc.html#a86e2bb172f766ab4a620df482d2fe481',1,'ProSHADE_internal_misc']]],
   ['addtounsptrvector_14',['addToUnsPtrVector',['../namespace_pro_s_h_a_d_e__internal__misc.html#ae36ae89607a7676c427956b88751f639',1,'ProSHADE_internal_misc']]],
-  ['addzeropeaktogroups_15',['addZeroPeakToGroups',['../namespace_pro_s_h_a_d_e__internal__symmetry.html#ade9b717260e86c8f24bcbe6d17fe4e06',1,'ProSHADE_internal_symmetry']]],
-  ['advanceglpolyvalue_16',['advanceGLPolyValue',['../namespace_pro_s_h_a_d_e__internal__maths.html#a4f2619c7f3b8d628af9cb356778e9807',1,'ProSHADE_internal_maths']]],
-  ['alldetectedcaxes_17',['allDetectedCAxes',['../class_pro_s_h_a_d_e__settings.html#a2ac59de43dacdd96c7f89811f80d2e7e',1,'ProSHADE_settings']]],
-  ['alldetecteddaxes_18',['allDetectedDAxes',['../class_pro_s_h_a_d_e__settings.html#a618c04a2c1d7f0a506d0bb3d7a0da444',1,'ProSHADE_settings']]],
-  ['alldetectediaxes_19',['allDetectedIAxes',['../class_pro_s_h_a_d_e__settings.html#aa4957b0a47193ef1042028dc22b350f6',1,'ProSHADE_settings']]],
-  ['alldetectedoaxes_20',['allDetectedOAxes',['../class_pro_s_h_a_d_e__settings.html#a4d869a528d0af64bc3688a9a48514061',1,'ProSHADE_settings']]],
-  ['alldetectedtaxes_21',['allDetectedTAxes',['../class_pro_s_h_a_d_e__settings.html#ae42ba1e294d1887c71b763f9bb5519cc',1,'ProSHADE_settings']]],
+  ['advanceglpolyvalue_15',['advanceGLPolyValue',['../namespace_pro_s_h_a_d_e__internal__maths.html#a4f2619c7f3b8d628af9cb356778e9807',1,'ProSHADE_internal_maths']]],
+  ['alldetectedcaxes_16',['allDetectedCAxes',['../class_pro_s_h_a_d_e__settings.html#a2ac59de43dacdd96c7f89811f80d2e7e',1,'ProSHADE_settings']]],
+  ['alldetecteddaxes_17',['allDetectedDAxes',['../class_pro_s_h_a_d_e__settings.html#a618c04a2c1d7f0a506d0bb3d7a0da444',1,'ProSHADE_settings']]],
+  ['alldetectediaxes_18',['allDetectedIAxes',['../class_pro_s_h_a_d_e__settings.html#aa4957b0a47193ef1042028dc22b350f6',1,'ProSHADE_settings']]],
+  ['alldetectedoaxes_19',['allDetectedOAxes',['../class_pro_s_h_a_d_e__settings.html#a4d869a528d0af64bc3688a9a48514061',1,'ProSHADE_settings']]],
+  ['alldetectedtaxes_20',['allDetectedTAxes',['../class_pro_s_h_a_d_e__settings.html#ae42ba1e294d1887c71b763f9bb5519cc',1,'ProSHADE_settings']]],
+  ['allocatecentreofmapfouriertransforms_21',['allocateCentreOfMapFourierTransforms',['../namespace_pro_s_h_a_d_e__internal__symmetry.html#a952318f67deb547d73ae3ed62ee6d5c4',1,'ProSHADE_internal_symmetry']]],
   ['allocatecomputationmemory_22',['allocateComputationMemory',['../namespace_pro_s_h_a_d_e__internal__spherical_harmonics.html#aefc1302e14aeda70290390bda39da952',1,'ProSHADE_internal_sphericalHarmonics']]],
   ['allocateematrices_23',['allocateEMatrices',['../class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a4e78c033b2c8c038038887105d67b115',1,'ProSHADE_internal_data::ProSHADE_data']]],
   ['allocateinvsoftworkspaces_24',['allocateInvSOFTWorkspaces',['../namespace_pro_s_h_a_d_e__internal__distances.html#adf3050bb282928f5c1639dcdf2b3261f',1,'ProSHADE_internal_distances']]],
@@ -39,10 +39,10 @@ var searchData=
   ['angulardistancewithborders_36',['angularDistanceWithBorders',['../class_pro_s_h_a_d_e__internal__spheres_1_1_pro_s_h_a_d_e__rot_fun__sphere_peak_group.html#a8edbe0a36f9af831a2160455386863ba',1,'ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup']]],
   ['appliedmaskfilename_37',['appliedMaskFileName',['../class_pro_s_h_a_d_e__settings.html#a670cffe28bbdac027bffd8f5491d4266',1,'ProSHADE_settings']]],
   ['applycondonshortleyphase_38',['applyCondonShortleyPhase',['../namespace_pro_s_h_a_d_e__internal__spherical_harmonics.html#aa25c84ea82e4faeb0f41f738a56ca28d',1,'ProSHADE_internal_sphericalHarmonics']]],
-  ['applymask_39',['applyMask',['../namespace_pro_s_h_a_d_e__internal__io.html#aa5e21f1b3dc18338da35951b248e6e38',1,'ProSHADE_internal_io']]],
-  ['applymaskfromarray_40',['applyMaskFromArray',['../namespace_pro_s_h_a_d_e__internal__io.html#a354a3899d17c6c5d4bad042dc00f4554',1,'ProSHADE_internal_io']]],
-  ['applyweights_41',['applyWeights',['../namespace_pro_s_h_a_d_e__internal__io.html#a2047cb9106e44b8de3174e34b9578f80',1,'ProSHADE_internal_io']]],
-  ['applyweightsfromarray_42',['applyWeightsFromArray',['../namespace_pro_s_h_a_d_e__internal__io.html#adae94658a4eec4c994e10d267b00fe4c',1,'ProSHADE_internal_io']]],
+  ['applymask_39',['applyMask',['../namespace_pro_s_h_a_d_e__internal__io.html#a1e3fc8ac7658bf54776a0fbb4e8286cd',1,'ProSHADE_internal_io']]],
+  ['applymaskfromarray_40',['applyMaskFromArray',['../namespace_pro_s_h_a_d_e__internal__io.html#a3fa28eb91fd8504c7397f76f4202ddb8',1,'ProSHADE_internal_io']]],
+  ['applyweights_41',['applyWeights',['../namespace_pro_s_h_a_d_e__internal__io.html#a189c98238a6caef5d7dfde5cde999709',1,'ProSHADE_internal_io']]],
+  ['applyweightsfromarray_42',['applyWeightsFromArray',['../namespace_pro_s_h_a_d_e__internal__io.html#a89bc3f1b071b14daf8795335b139c85b',1,'ProSHADE_internal_io']]],
   ['arraymedianandiqr_43',['arrayMedianAndIQR',['../namespace_pro_s_h_a_d_e__internal__maths.html#aa5a356017340781739a3bd66c716cfa5',1,'ProSHADE_internal_maths']]],
   ['autodeterminebandwidth_44',['autoDetermineBandwidth',['../namespace_pro_s_h_a_d_e__internal__spheres.html#a9592e9df40cf87ee1d1c43d6b3508e1c',1,'ProSHADE_internal_spheres']]],
   ['autodetermineintegrationorder_45',['autoDetermineIntegrationOrder',['../namespace_pro_s_h_a_d_e__internal__spheres.html#a612cf0a1e92ea1e5f0b9bdb820a4b60e',1,'ProSHADE_internal_spheres']]],
