@@ -19,8 +19,8 @@
 #
 #   \author    Michal Tykac
 #   \author    Garib N. Murshudov
-#   \version   0.7.6.3
-#   \date      FEB 2022
+#   \version   0.7.6.4
+#   \date      APR 2022
 ######################################################
 ######################################################
 
@@ -60,7 +60,8 @@ ps.setBandwidth                                       ( 0 )
 ps.setPhaseUsage                                      ( True )                                                           # Use full maps, or Patterson-like maps?
 ps.setSphereDistances                                 ( 0.0 )                                                            # The distance between spheres. Use 0.0 for automatic determination.
 ps.setIntegrationOrder                                ( 0 )                                                              # The order of the Gauss-Legendre integration computation. Set to 0 for automatic determination.
-ps.setTaylorSeriesCap                                 ( 10 )                                                             # Set the Taylor series approximation cap. 10 seems like a fast and accurate value, but feel free to change.
+ps.setIntegrationApproxSteps                          ( 5 )                                                              # Set the number of steps in the Gauss-Legendre quadrature approximation.
+ps.setIntegrationSpeedUp                              ( True )                                                           # Should the computation be spead up using the integration improvement?
 ps.setNormalisation                                   ( False )                                                          # Should internal map representation be normalised to mean 0 and standard deviation 1?
 ps.setMapInversion                                    ( False )                                                          # Should all map positions x,y,z be swapped to -x,-y,-z? Use this only if your helices have the wrong hand as a result of first runs of map computation.
 ps.setMasking                                         ( False )                                                          # Should maps be masked by blurring?
@@ -118,8 +119,8 @@ print                                                 ( "Full rotation function
 ######################################################
 ### Expected output
 #   Energy levels distance          : 0.8556063        0.5606434
-#   Trace sigma distance            : 0.96467125       0.7530951
-#   Full rotation function distance : 0.62452674       0.46518552
+#   Trace sigma distance            : 0.977767        0.63715816
+#   Full rotation function distance : 0.6000013        0.3371659
 
 ######################################################
 ### Release memory
