@@ -19,8 +19,8 @@
 #
 #   \author    Michal Tykac
 #   \author    Garib N. Murshudov
-#   \version   0.7.6.3
-#   \date      FEB 2022
+#   \version   0.7.6.4
+#   \date      APR 2022
 ######################################################
 ######################################################
 
@@ -89,7 +89,8 @@ ps.setBandwidth                                       ( 0 )
 ps.setPhaseUsage                                      ( True )                       # Use full maps, or Patterson-like maps?
 ps.setSphereDistances                                 ( 0.0 )                        # The distance between spheres. Use 0.0 for automatic determination.
 ps.setIntegrationOrder                                ( 0 )                          # The order of the Gauss-Legendre integration computation. Set to 0 for automatic determination.
-ps.setTaylorSeriesCap                                 ( 10 )                         # Set the Taylor series approximation cap. 10 seems like a fast and accurate value, but feel free to change.
+ps.setIntegrationApproxSteps                          ( 5 )                          # Set the number of steps in the Gauss-Legendre quadrature approximation.
+ps.setIntegrationSpeedUp                              ( True )                       # Should the computation be spead up using the integration improvement?
 ps.setProgressiveSphereMapping                        ( False )                      # Should smaller spheres be less sampled? It is considerably faster, but may sacrifice some (little) accuracy.
 ps.setEnergyLevelsComputation                         ( True )                       # Should energy levels descriptor be computed, assuming Distances are required (irrelevant otherwise)?
 ps.setTraceSigmaComputation                           ( True )                       # Should trace sigma descriptor be computed, assuming Distances are required (irrelevant otherwise)?
@@ -124,4 +125,4 @@ del rn
 del ps
 
 ######################################################
-### Done
+### Done 
