@@ -49,6 +49,10 @@
 #include <stdlib.h>
 #include <string.h>
 
+#ifndef M_PI
+    #define M_PI 3.14159265358979323846
+#endif
+
 #include "fftw3.h"
 
 #include "makeweights.h"
