@@ -15,8 +15,8 @@
  
     \author    Michal Tykac
     \author    Garib N. Murshudov
-    \version   0.7.6.3
-    \date      FEB 2022
+    \version   0.7.6.4
+    \date      APR 2022
  */
 
 //==================================================== ProSHADE
@@ -67,7 +67,8 @@ public:
     
     //================================================ Settings regarding the Gauss-Legendre integration
     proshade_unsign integOrder;                       //!< The order required for full Gauss-Legendre integration between the spheres.
-    proshade_unsign taylorSeriesCap;                  //!< The max limit on the Taylor series expansion done for the abscissas of the Gauss-Legendre integration.
+    proshade_unsign integApproxSteps;                 //!< The number of steps taken in the approximation of Legendre polynomial decomposition to terms.
+    bool noIntegrationSpeedup;                        //!< This option turns off the integration speedup (only using abscissas and weights up to appropriate l for each E matrix index).
     
     //================================================ Settings regarding map normalisation
     bool normaliseMap;                                //!< Should the map be normalised to mean 0 sd 1?
@@ -216,7 +217,8 @@ public:
     void __declspec(dllexport) setBandwidth                                   ( proshade_unsign band );
     void __declspec(dllexport) setSphereDistances                             ( proshade_single sphDist );
     void __declspec(dllexport) setIntegrationOrder                            ( proshade_unsign intOrd );
-    void __declspec(dllexport) setTaylorSeriesCap                             ( proshade_unsign tayCap );
+    void __declspec(dllexport) setIntegrationApproxSteps                      ( proshade_unsign noSteps );
+    void __declspec(dllexport) setIntegrationSpeedUp                          ( bool speedup );
     void __declspec(dllexport) setProgressiveSphereMapping                    ( bool progSphMap );
     void __declspec(dllexport) setEnergyLevelsComputation                     ( bool enLevDesc );
     void __declspec(dllexport) setTraceSigmaComputation                       ( bool trSigVal );
@@ -275,7 +277,8 @@ public:
     void setBandwidth                                 ( proshade_unsign band );
     void setSphereDistances                           ( proshade_single sphDist );
     void setIntegrationOrder                          ( proshade_unsign intOrd );
-    void setTaylorSeriesCap                           ( proshade_unsign tayCap );
+    void setIntegrationApproxSteps                    ( proshade_unsign noSteps );
+    void setIntegrationSpeedUp                        ( bool speedup );
     void setProgressiveSphereMapping                  ( bool progSphMap );
     void setEnergyLevelsComputation                   ( bool enLevDesc );
     void setTraceSigmaComputation                     ( bool trSigVal );
